summaryrefslogtreecommitdiffstats
path: root/qmake/project.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qmake/project.cpp')
-rw-r--r--qmake/project.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/qmake/project.cpp b/qmake/project.cpp
index f60dba06a..0f8eca3f9 100644
--- a/qmake/project.cpp
+++ b/qmake/project.cpp
@@ -84,7 +84,7 @@ TQStringList qmake_mkspec_paths()
ret << ((*it) + concat);
#endif
}
- if(const char *qtdir = getenv("QTDIR"))
+ if(const char *qtdir = getenv("TQTDIR"))
ret << (TQString(qtdir) + concat);
#ifdef QT_INSTALL_PREFIX
ret << (QT_INSTALL_PREFIX + concat);
@@ -99,9 +99,9 @@ TQStringList qmake_mkspec_paths()
ret << (tqInstallPathData() + concat);
#endif
- /* prefer $QTDIR if it is set */
- if (getenv("QTDIR"))
- ret << getenv("QTDIR");
+ /* prefer $TQTDIR if it is set */
+ if (getenv("TQTDIR"))
+ ret << getenv("TQTDIR");
ret << tqInstallPathData();
return ret;
}
@@ -925,7 +925,7 @@ TQMakeProject::doProjectTest(const TQString& func, TQStringList args, TQMap<TQSt
#endif
}
feature_roots << Option::mkfile::qmakespec;
- if(const char *qtdir = getenv("QTDIR"))
+ if(const char *qtdir = getenv("TQTDIR"))
feature_roots << (qtdir + concat);
#ifdef QT_INSTALL_PREFIX
feature_roots << (QT_INSTALL_PREFIX + concat);